# THIS FILE IS GENERATED BY SETUP.PY
# DO NOT MODIFY BY HAND
version = '5.6.0'
git_version = '25176e88e62005fa322257b37278d8f72d9e0378'
full_version = '5.6.0'
is_release = True

if not is_release:
    version = full_version